import React, { forwardRef, useState, useImperativeHandle, useEffect, Fragment } from 'react';

function getBodyScrollPosition() {
  return Math.max(document.documentElement && document.documentElement.scrollTop, document.body && document.body.scrollTop, document.scrollingElement && document.scrollingElement.scrollTop);
}
function getBodyScrollHeight() {
  return Math.max(document.documentElement && document.documentElement.scrollHeight, document.body && document.body.scrollHeight, document.scrollingElement && document.scrollingElement.scrollHeight);
}

var InfiniteScroll = forwardRef(function (props, ref) {
  var children = props.children,
      dataLength = props.dataLength,
      loadMore = props.loadMore,
      hasMore = props.hasMore,
      loader = props.loader,
      threshold = props.threshold,
      parentRef = props.parentRef,
      startPage = props.startPage,
      loadFirstSetOnInit = props.loadFirstSetOnInit,
      resetDependencies = props.resetDependencies,
      disabled = props.disabled;
  var defaultThreshold = 250;

  var _useState = useState(startPage && startPage >= 0 ? startPage : 0),
      firstPage = _useState[0],
      setFirstPage = _useState[1];

  var _useState2 = useState(firstPage),
      page = _useState2[0],
      setPage = _useState2[1];

  var _useState3 = useState(dataLength),
      currentDataLength = _useState3[0],
      setCurrentDataLength = _useState3[1];

  var _useState4 = useState([]),
      pagesLoaded = _useState4[0],
      setPagesLoaded = _useState4[1];

  var externalResetDependencies = Array.isArray(resetDependencies) ? resetDependencies : [resetDependencies];

  var reset = function reset(resetTo) {
    if (resetTo === void 0) {
      resetTo = {};
    }

    var _resetTo = resetTo,
        resetToStartPage = _resetTo.startPage;

    if (Number.isInteger(resetToStartPage) && resetToStartPage >= 0) {
      setFirstPage(resetToStartPage);
      setPage(resetToStartPage);
    } else {
      setPage(firstPage);
    }

    setCurrentDataLength(dataLength);
    setPagesLoaded([]);
  };

  useImperativeHandle(ref, function () {
    return {
      reset: reset
    };
  });
  useEffect(function () {
    reset();
  }, externalResetDependencies);
  useEffect(function () {
    if (!Number.isInteger(currentDataLength)) {
      console.error('InfiniteScroll: dataLength prop is not a number', currentDataLength);
    }

    if (dataLength > currentDataLength) {
      setPage(page + 1);
    }

    setCurrentDataLength(dataLength);
  }, [dataLength]);
  useEffect(function () {
    if (disabled) {
      return;
    }

    var parentElement = parentRef === null || parentRef === void 0 ? void 0 : parentRef.current;

    var handle = function handle() {
      var scrollPosition = parentElement ? parentElement.scrollTop + parentElement.offsetHeight : getBodyScrollPosition() + window.innerHeight;
      var scrollHeight = parentElement ? parentElement.scrollHeight : getBodyScrollHeight();
      var loadOnInit = loadFirstSetOnInit && page === firstPage;
      var thresholdExceeded = scrollHeight - scrollPosition < (threshold || defaultThreshold);
      var isPageLoaded = pagesLoaded.includes(page);

      if ((loadOnInit || hasMore && thresholdExceeded) && !isPageLoaded) {
        setPagesLoaded([].concat(pagesLoaded, [page]));
        loadMore(page);
      }
    };

    handle();
    (parentElement || window).addEventListener('scroll', handle);
    (parentElement || window).addEventListener('resize', handle);
    return function () {
      (parentElement || window).removeEventListener('scroll', handle);
      (parentElement || window).removeEventListener('resize', handle);
    };
  }, [page, pagesLoaded, hasMore, disabled]);
  return React.createElement(Fragment, null, children, hasMore && loader);
});

export default InfiniteScroll;
//# sourceMappingURL=index.modern.js.map
